==> scanbot_sdk-2.9.0.tar.gz: ios/Classes/Extensions/SDK/Generic Document Recognizer/SBSDKUIGenericDocumentRecognizerUIConfiguration.swift <==
//
//  SBSDKUIGenericDocumentRecognizerUIConfiguration.swift
//  scanbot_sdk
//
//  Created by Sarbjyot Chahal on 12.01.22.
//

import Foundation
import ScanbotSDK

extension SBSDKUIGenericDocumentRecognizerUIConfiguration {
    convenience init(from dictionary: [String: Any]) {
        self.init()
        
        if let hex = dictionary["topBarButtonsColor"] as? String {
            self.topBarButtonsColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["topBarBackgroundColor"] as? String {
            self.topBarBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["topBarButtonsInactiveColor"] as? String {
            self.topBarButtonsInactiveColor = UIColor(hexString: hex)
        }
        
        
        if let hex = dictionary["cameraOverlayColor"] as? String {
            self.cameraOverlayColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["finderLineColor"] as? String {
            self.finderLineColor = UIColor(hexString: hex)
        }
        
        if let float = dictionary["finderLineWidth"] as? CGFloat {
            self.finderLineWidth = float
        }
        
        if let isCancelButtonHidden = dictionary["cancelButtonHidden"] as? Bool {
            self.isCancelButtonHidden = isCancelButtonHidden
        }
        
        if let string = dictionary["orientationLockMode"] as? String {
            let allowedInterfaceOrientations = UIInterfaceOrientationMask(from: string)
            self.allowedInterfaceOrientations = allowedInterfaceOrientations
        }
        
        if let hex = dictionary["fieldsCountTextColor"] as? String {
            self.fieldsCountTextColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["detailsPrimaryColor"] as? String {
            self.detailsPrimaryColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["detailsActionColor"] as? String {
            self.detailsActionColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["detailsSectionHeaderTextColor"] as? String {
            self.detailsSectionHeaderTextColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["detailsSectionHeaderBackgroundColor"] as? String {
            self.detailsSectionHeaderBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["detailsBackgroundColor"] as? String {
            self.detailsBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["fieldConfidenceHighColor"] as? String {
            self.fieldConfidenceHighColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["fieldConfidenceModerateColor"] as? String {
            self.fieldConfidenceModerateColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["fieldConfidenceLowColor"] as? String {
            self.fieldConfidenceLowColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["fieldConfidenceTextColor"] as? String {
            self.fieldConfidenceTextColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["tipTextColor"] as? String {
            self.tipTextColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["tipBackgroundColor"] as? String {
            self.tipBackgroundColor = UIColor(hexString: hex)
        }
  
    }
}

==> scanbot_sdk-2.10.0.tar.gz: ios/Classes/Extensions/SDK/Generic Document Recognizer/SBSDKUIGenericDocumentRecognizerUIConfiguration.swift <==
//
//  SBSDKUIGenericDocumentRecognizerUIConfiguration.swift
//  scanbot_sdk
//
//  Created by Sarbjyot Chahal on 12.01.22.
//

import Foundation
import ScanbotSDK

extension SBSDKUIGenericDocumentRecognizerUIConfiguration {
    convenience init(from dictionary: [String: Any]) {
        self.init()
        
        if let hex = dictionary["topBarButtonsColor"] as? String {
            self.topBarButtonsColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["topBarBackgroundColor"] as? String {
            self.topBarBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["topBarButtonsInactiveColor"] as? String {
            self.topBarButtonsInactiveColor = UIColor(hexString: hex)
        }
        
        
        if let hex = dictionary["cameraOverlayColor"] as? String {
            self.cameraOverlayColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["finderLineColor"] as? String {
            self.finderLineColor = UIColor(hexString: hex)
        }
        
        if let float = dictionary["finderLineWidth"] as? CGFloat {
            self.finderLineWidth = float
        }
        
        if let isCancelButtonHidden = dictionary["cancelButtonHidden"] as? Bool {
            self.isCancelButtonHidden = isCancelButtonHidden
        }
        
        if let string = dictionary["orientationLockMode"] as? String {
            let orientationLockMode = SBSDKOrientationLock(from: string)
            self.orientationLockMode = orientationLockMode
        }
        
        if let hex = dictionary["fieldsCountTextColor"] as? String {
            self.fieldsCountTextColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["detailsPrimaryColor"] as? String {
            self.detailsPrimaryColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["detailsActionColor"] as? String {
            self.detailsActionColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["detailsSectionHeaderTextColor"] as? String {
            self.detailsSectionHeaderTextColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["detailsSectionHeaderBackgroundColor"] as? String {
            self.detailsSectionHeaderBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["detailsBackgroundColor"] as? String {
            self.detailsBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["fieldConfidenceHighColor"] as? String {
            self.fieldConfidenceHighColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["fieldConfidenceModerateColor"] as? String {
            self.fieldConfidenceModerateColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["fieldConfidenceLowColor"] as? String {
            self.fieldConfidenceLowColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["fieldConfidenceTextColor"] as? String {
            self.fieldConfidenceTextColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["tipTextColor"] as? String {
            self.tipTextColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["tipBackgroundColor"] as? String {
            self.tipBackgroundColor = UIColor(hexString: hex)
        }
  
    }
}
